==> lightning-0.8.1.tar.gz: lib/src/view/utility/html0.dart <==
/*
 * Copyright (c) 2015 Accorto, Inc. All Rights Reserved
 * License: GPLv3   http://www.gnu.org/licenses/gpl-3.0.txt
 * License options+support:  https://www.lightningdart.com
 */

part of lightning_dart;

/**
 * Html Constants
 */
class Html0 {

  // http://www.w3.org/TR/2007/WD-xhtml-role-20071004/
  /// Attribute: role
  static const String ROLE = "role";
  /// Attribute role Value
  static const String ROLE_BANNER = "banner";
  /// Attribute role Value
  static const String ROLE_CONTENTINFO = "contentinfo";
  /// Attribute role Value
  static const String ROLE_DEFINITION = "definition";
  /// Attribute role Value
  static const String ROLE_MAIN = "main";
  /// Attribute role Value
  static const String ROLE_NAVIGATION = "navigarion";
  /// Attribute role Value
  static const String ROLE_NOTE = "note";
  /// Attribute role Value
  static const String ROLE_SEARCH = "search";
  /// Attribute role Value
  static const String ROLE_SECONDARY = "secondary";
  /// Attribute role Value
  static const String ROLE_SEEALSO = "seealso";

  // http://www.w3.org/TR/wai-aria/roles
  // http://www.w3.org/TR/wai-aria/rdf_model.svg
  /// Aria Attribute role Value
  static const String ROLE_ALERT = "alert";
  /// Aria Attribute role Value
  static const String ROLE_PRESENTATION = "presentation";
  /// Aria Attribute role Value
  static const String ROLE_LISTBOX = "listbox";
  /// Aria Attribute role Value
  static const String ROLE_COMBOBOX = "combobox";
  /// Aria Attribute role Value
  static const String ROLE_OPTION = "option";
  /// Aria Attribute role Value
  static const String ROLE_GROUP = "group";
  /// Aria Attribute role Value
  static const String ROLE_MENU = "menu";
  /// Aria Attribute role Value
  static const String ROLE_MENUITEM = "menuitem";
  /// Aria Attribute role Value
  static const String ROLE_MENUITEMCHECKBOX = "menuitemcheckbox";
  /// Aria Attribute role Value
  static const String ROLE_MENUITEMRADIO = "menuitemradio";

  /// Aria Attribute role Value
  static const String ROLE_DIALOG = "dialog";
  /// Aria Attribute role Value
  static const String ROLE_DOCUMENT = "document";
  /// Aria Attribute role Value
  static const String ROLE_TOOLTIP = "tooltip";
  /// Aria Attribute role Value
  static const String ROLE_TAB = "tab";
  /// Aria Attribute role Value
  static const String ROLE_TABLIST = "tablist";
  /// Aria Attribute role Value
  static const String ROLE_TABPANEL = "tabpanel";



  /// Attribute Aria Labelled By
  static const String ARIA_LABELLEDBY = "aria-labelledby";
  /// Attribute Aria Label
  static const String ARIA_LABEL = "aria-label";
  /// Attribute Aria
  static const String ARIA_DISABLED = "aria-disabled";
  /// Attribute Aria
  static const String ARIA_HIDDEN = "aria-hidden";
  /// Attribute Aria
  static const String ARIA_SELECTED = "aria-selected";

  /// Attribute Aria auto complete e.g. list
  static const String ARIA_AUTOCOMPLETE = "aria-autocomplete";
  static const String ARIA_AUTOCOMPLETE_LIST = "list";
  /// Attribute Aria
  static const String ARIA_HASPOPUP = "aria-haspopup";
  /// Attribute Aria live assertive
  static const String ARIA_LIVE = "aria-live";
  static const String ARIA_LIVE_ASSERTIVE = "assertive";

  /// Attribute Aria
  static const String ARIA_EXPANED = "aria-expanded";
  /// Attribute Aria
  static const String ARIA_ACTIVEDECENDNT = "aria-activedescendant";

  /// Disabled attribute
  static const String DISABLED = "disabled";

  /// Data Attribute - Data Column Name
  static const String DATA_NAME = "data-name";
  /// Data Attribute - Data Column Label
  static const String DATA_LABEL = "data-label";
  /// Data Attribute - Data Value
  static const String DATA_VALUE = "data-value";


} // Html0

==> lightning-0.12.1.tar.gz: lib/src/view/utility/html0.dart <==
/*
 * Copyright (c) 2015 Accorto, Inc. All Rights Reserved
 * License: GPLv3   http://www.gnu.org/licenses/gpl-3.0.txt
 * License options+support:  https://www.lightningdart.com
 */

part of lightning_dart;

/**
 * Html Constants
 */
class Html0 {

  /// Non breaking Space (unicode)
  static const String SPACE_NB = "\u00A0"; // nbsp

  // http://www.w3.org/TR/2007/WD-xhtml-role-20071004/
  /// Attribute: role
  static const String ROLE = "role";
  /// Attribute role Value
  static const String ROLE_BANNER = "banner";
  /// Attribute role Value
  static const String ROLE_CONTENTINFO = "contentinfo";
  /// Attribute role Value
  static const String ROLE_DEFINITION = "definition";
  /// Attribute role Value
  static const String ROLE_MAIN = "main";
  /// Attribute role Value
  static const String ROLE_NAVIGATION = "navigarion";
  /// Attribute role Value
  static const String ROLE_NOTE = "note";
  /// Attribute role Value
  static const String ROLE_SEARCH = "search";
  /// Attribute role Value
  static const String ROLE_SECONDARY = "secondary";
  /// Attribute role Value
  static const String ROLE_SEEALSO = "seealso";

  // http://www.w3.org/TR/wai-aria/roles
  // http://www.w3.org/TR/wai-aria/rdf_model.svg
  /// Aria Attribute role Value
  static const String ROLE_ALERT = "alert";
  /// Aria Attribute role Value
  static const String ROLE_PRESENTATION = "presentation";
  /// Aria Attribute role Value
  static const String ROLE_BUTTON = "button";
  /// Aria Attribute role Value
  static const String ROLE_LISTBOX = "listbox";
  /// Aria Attribute role Value
  static const String ROLE_COMBOBOX = "combobox";
  /// Aria Attribute role Value
  static const String ROLE_OPTION = "option";
  /// Aria Attribute role Value
  static const String ROLE_GROUP = "group";
  /// Aria Attribute role Value
  static const String ROLE_MENU = "menu";
  /// Aria Attribute role Value
  static const String ROLE_MENUITEM = "menuitem";
  /// Aria Attribute role Value
  static const String ROLE_MENUITEMCHECKBOX = "menuitemcheckbox";
  /// Aria Attribute role Value
  static const String ROLE_MENUITEMRADIO = "menuitemradio";

  /// Aria Attribute role Value
  static const String ROLE_ROW = "row";
  /// Aria Attribute role Value
  static const String ROLE_DIALOG = "dialog";
  /// Aria Attribute role Value
  static const String ROLE_DOCUMENT = "document";
  /// Aria Attribute role Value
  static const String ROLE_TOOLTIP = "tooltip";
  /// Aria Attribute role Value
  static const String ROLE_TAB = "tab";
  /// Aria Attribute role Value
  static const String ROLE_TABLIST = "tablist";
  /// Aria Attribute role Value
  static const String ROLE_TABPANEL = "tabpanel";
  /// Aria Attribute role Value
  static const String ROLE_HEADING = "heading";
  /// Aria Attribute role Value
  static const String ROLE_GRID = "grid";
  /// Aria Attribute role Value
  static const String ROLE_GRIDCELL = "gridcell";


  /// Attribute Aria Labelled By (id)
  static const String ARIA_LABELLEDBY = "aria-labelledby";
  /// Attribute Aria Controls (id)
  static const String ARIA_CONTROLS = "aria-controls";
  /// Attribute Aria Label
  static const String ARIA_LABEL = "aria-label";
  /// Attribute Aria
  static const String ARIA_DISABLED = "aria-disabled";
  /// Attribute Aria
  static const String ARIA_HIDDEN = "aria-hidden";
  /// Attribute Aria
  static const String ARIA_SELECTED = "aria-selected";

  /// Attribute Aria auto complete e.g. list
  static const String ARIA_AUTOCOMPLETE = "aria-autocomplete";
  static const String ARIA_AUTOCOMPLETE_LIST = "list";
  /// Attribute Aria
  static const String ARIA_HASPOPUP = "aria-haspopup";
  /// Attribute Aria live assertive
  static const String ARIA_LIVE = "aria-live";
  static const String ARIA_LIVE_ASSERTIVE = "assertive";

  static const String ARIA_ATOMIC = "aria-atomic";

  /// Attribute Aria
  static const String ARIA_EXPANED = "aria-expanded";
  /// Attribute Aria
  static const String ARIA_ACTIVEDECENDNT = "aria-activedescendant";

  /// Disabled attribute
  static const String DISABLED = "disabled";

  /// Data Attribute - Data Column ID
  static const String DATA_ID = "data-id";
  /// Data Attribute - Data Column Name
  static const String DATA_NAME = "data-name";
  /// Data Attribute - Data Column Label
  static const String DATA_LABEL = "data-label";
  /// Data Attribute - Data Value
  static const String DATA_VALUE = "data-value";


  /// Constant Value True
  static const String V_TRUE = "true";
  /// Constant Value False
  static const String V_FALSE = "false";


} // Html0
